# Tutorials

``` {toctree}
:maxdepth: 1
:hidden:

../colabs/visualization_modality_tour
../colabs/variant_scoring_ui
../colabs/tissue_ontology_mapping
../colabs/batch_variant_scoring
../colabs/example_analysis_workflow
```

<!-- mdformat off(Turn off mdformat to retain grid card syntax.) -->

::::{grid} 1 1 2 3
:gutter: 2

:::{grid-item-card} Visualizing predictions
:link: ../colabs/visualization_modality_tour
:link-type: doc

How to visualize different output modalities.
:::

:::{grid-item-card} Scoring and visualizing a single variant
:link: ../colabs/variant_scoring_ui
:link-type: doc

Tool for scoring and visualizing a single variant across multiple modalities.
:::

:::{grid-item-card} Navigating data ontologies
:link: ../colabs/tissue_ontology_mapping
:link-type: doc

Tool for fetching ontology IDs for a given tissue.

:::

:::{grid-item-card} Batch variant scoring
:link: ../colabs/batch_variant_scoring
:link-type: doc

Tool for scoring many variants at once.
:::

:::{grid-item-card} Example analysis workflow
:link: ../colabs/example_analysis_workflow
:link-type: doc

Example analysis of TAL1 locus.
:::

<!-- mdformat on -->
